@@ -1,43 +1,47 @@
 #![no_std]
 #![no_main]
 
-use bsp::hal;
 use metro_m4 as bsp;
 
+use bsp::hal;
+use bsp::pac;
+
 #[cfg(not(feature = "use_semihosting"))]
 use panic_halt as _;
 #[cfg(feature = "use_semihosting")]
 use panic_semihosting as _;
-use smart_leds;
-use ws2812_timer_delay as ws2812;
 
 use bsp::entry;
-use embedded_hal::digital::v1_compat::OldOutputPin;
-use hal::pac::{CorePeripherals, Peripherals};
+use hal::clock::GenericClockController;
+use hal::delay::Delay;
 use hal::prelude::*;
-use hal::timer::SpinTimer;
-use hal::{clock::GenericClockController, delay::Delay};
+use hal::timer::TimerCounter;
+use pac::{CorePeripherals, Peripherals};
 
 use smart_leds::{
     hsv::{hsv2rgb, Hsv},
     SmartLedsWrite,
 };
+use ws2812_timer_delay as ws2812;
 
 #[entry]
 fn main() -> ! {
     let mut peripherals = Peripherals::take().unwrap();
     let core = CorePeripherals::take().unwrap();
-    let mut clocks = GenericClockController::with_internal_32kosc(
+    let mut clocks = GenericClockController::with_external_32kosc(
         peripherals.GCLK,
         &mut peripherals.MCLK,
         &mut peripherals.OSC32KCTRL,
         &mut peripherals.OSCCTRL,
         &mut peripherals.NVMCTRL,
     );
-    let mut pins = bsp::Pins::new(peripherals.PORT);
+    let gclk0 = clocks.gclk0();
+    let tc2_3 = clocks.tc2_tc3(&gclk0).unwrap();
+    let mut timer = TimerCounter::tc3_(&tc2_3, peripherals.TC3, &mut peripherals.MCLK);
+    timer.start(3.mhz());
 
-    let timer = SpinTimer::new(4);
-    let neopixel_pin: OldOutputPin<_> = pins.neopixel.into_push_pull_output(&mut pins.port).into();
+    let pins = bsp::Pins::new(peripherals.PORT);
+    let neopixel_pin = pins.neopixel.into_push_pull_output();
     let mut neopixel = ws2812::Ws2812::new(timer, neopixel_pin);
     let mut delay = Delay::new(core.SYST, &mut clocks);
 
