@@ -1,20 +1,19 @@
 #![no_std]
 #![no_main]
 
+use cortex_m_rt::entry;
+use panic_halt as _;
+
 use bsp::hal;
+use bsp::pac;
 use metro_m4 as bsp;
 
-#[cfg(not(feature = "use_semihosting"))]
-use panic_halt as _;
-#[cfg(feature = "use_semihosting")]
-use panic_semihosting as _;
-
-use cortex_m_rt::entry;
 use hal::clock::GenericClockController;
 use hal::delay::Delay;
-use hal::pac::{CorePeripherals, Peripherals};
+use hal::gpio::v2::E;
 use hal::prelude::*;
-use hal::pwm::Pwm2;
+use hal::pwm::{Pwm2, TC2Pinout};
+use pac::{CorePeripherals, Peripherals};
 
 #[entry]
 fn main() -> ! {
@@ -29,16 +28,16 @@ fn main() -> ! {
         &mut peripherals.NVMCTRL,
     );
     let mut delay = Delay::new(core.SYST, &mut clocks);
-    let mut pins = bsp::Pins::new(peripherals.PORT);
+    let pins = bsp::Pins::new(peripherals.PORT);
 
-    let d12 = pins.d12.into_function_e(&mut pins.port);
+    let d12 = pins.d12.into_alternate::<E>();
 
     let gclk0 = clocks.gclk0();
     let mut pwm2 = Pwm2::new(
         &clocks.tc2_tc3(&gclk0).unwrap(),
         1.khz(),
         peripherals.TC2,
-        hal::pwm::TC2Pinout::Pa17(d12),
+        TC2Pinout::Pa17(d12),
         &mut peripherals.MCLK,
     );
     let max_duty = pwm2.get_max_duty();
